<?php
	/**
	 * Set the content width based on the theme's design and stylesheet.
	 *
	 * @since beetheme 1.0
	 */
	if ( ! isset( $content_width ) ) {
		$content_width = 660;
	}
	/**
	 * Generating constant containing the absolute path for this theme
	 * Used to include PHP files
	 */
	if (!defined('BEETHEME_DIR')) {
	    define('BEETHEME_DIR', get_template_directory() . '/');
	}
	/**
	 * Generating constant containing the relative path for this theme
	 * Used to enqueue CSS and Javascript files
	 */
	if (!defined('BEETHEME_DIR_URI')) {
	    define('BEETHEME_DIR_URI', get_template_directory_uri() . '/');
	}
	/**
	 * load customizer and customizer control
	**/
	include BEETHEME_DIR. 'includes/customizer.php';
	include BEETHEME_DIR. 'includes/customizer-control.php';
	/**
	 * load aq_resize for image resize
	**/
	include BEETHEME_DIR. 'includes/aq_resize.php';
	/**
	 * load custom ajax call
	**/
	include BEETHEME_DIR. 'includes/ajaxcall.php';
	/**
	 * Beetheme stylesheet
	**/
	function beetheme_style() {
		wp_enqueue_style('bootstrap', BEETHEME_DIR_URI.'plugins/bootstrap/css/bootstrap.min.css');
		wp_enqueue_style('font-awesome',BEETHEME_DIR_URI.'plugins/font-awesome/css/font-awesome.min.css');
        wp_enqueue_style('animate',BEETHEME_DIR_URI.'plugins/animate/animate.css');
	    wp_enqueue_style('owl.carousel',BEETHEME_DIR_URI.'plugins/owl-carousel/owl.carousel.css');
		wp_enqueue_style('owl.theme',BEETHEME_DIR_URI.'plugins/owl-carousel/owl.theme.css');
		wp_enqueue_style('owl.transition',BEETHEME_DIR_URI.'plugins/owl-carousel/owl.transition.css');
		wp_enqueue_style('style', BEETHEME_DIR_URI.'style.css');
		wp_enqueue_style('slimbox2',BEETHEME_DIR_URI.'css/responsive.css');
		wp_enqueue_style('SansPro','https://fonts.googleapis.com/css?family=Source+Sans+Pro');
		wp_enqueue_style('Raleway','https://fonts.googleapis.com/css?family=Raleway:500');
	}
	add_action( 'wp_enqueue_scripts', 'beetheme_style' );
	/**
	 * Beetheme javascripts
	**/
	function beetheme_scripts(){
		wp_enqueue_script('jquery',BEETHEME_DIR_URI.'plugins/jQuery/jquery-1.12.4.min.js',array(jquery),'1.0.0',true);
	    wp_enqueue_script('bootstrap',BEETHEME_DIR_URI.'plugins/bootstrap/js/bootstrap.min.js',array(jquery),'1.0.0',true);
		wp_enqueue_script('owl', BEETHEME_DIR_URI.'plugins/owl-carousel/owl.carousel.min.js', array(jquery),'1.0.0',true );
		wp_enqueue_script('wow', BEETHEME_DIR_URI.'plugins/animate/wow.min.js', array(jquery),'1.0.0',true );
		wp_enqueue_script('jquery.mCustomScrollbar', BEETHEME_DIR_URI.'plugins/scrollbar/jquery.mCustomScrollbar.js', array(jquery),'1.0.0',true );
		wp_enqueue_script('isotops', BEETHEME_DIR_URI.'plugins/isotops/isotops.min.js', array(jquery),'1.0.0',true );
	    wp_enqueue_script('custom',BEETHEME_DIR_URI.'js/custom.js',array(jquery),'1.0.0',true);
	}
	add_action('wp_enqueue_scripts','beetheme_scripts');
	/**
	 * Beetheme Theme setup
	 */
	function beetheme_setup() {
		/**
		*
		*custom header
		*
		*/
		if( function_exists( 'has_custom_logo' ) ) {
			$args['height']        = 64;
			$args['width']         = 221;
		}
		add_theme_support( 'custom-header', $args );
		/**
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
	    add_theme_support('post-thumbnails');
	    set_post_thumbnail_size('post_thumbnail', 750, 359, true);
	    // Add default posts and comments RSS feed links to head.
	    add_theme_support('automatic-feed-links');
	    /*
	     * Switch default core markup for search form, comment form, and comments
	     * to output valid HTML5.
	     */
	    add_theme_support( 'html5', array(
	    	'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	    ) );
		//Load languages file
	    load_theme_textdomain('beetheme', BEETHEME_DIR_URI.'languages');
	    // This theme styles the visual editor to resemble the theme style.
	    add_editor_style();
	    //This feature enables plugins and themes to manage the document title tag. This should be used in place of wp_title() function.
	    add_theme_support("title-tag");
	    // Set up the WordPress core custom background feature.
	    add_theme_support( 'custom-background', apply_filters( 'beetheme_custom_background_args', array(
	    	'default-color' => '161616',
	    	'default-image' => '',
	    ) ) );
	    /**
	     * Enable support for custom logo.
	     *
	     */
	    add_theme_support( 'custom-logo', array(
	    	'height'      => 64,
	    	'width'       => 221,
	    	'flex-height' => true,
	    ) );
	    register_nav_menus(array(
	        //'front-page-menu' 		=> __('Front Page Menu', 'beetheme'),
	        'default-onepage-menu' 	=> __('Default OnePage Menu', 'beetheme'),
	        'sub-page-menu'			=> __('Sub Page Menu','beetheme'),
	    ));
	    $beetheme_post_formats = array( 
	    	'aside', 
	    	'gallery', 
	    	'link', 
	    	'image', 
	    	'quote', 
	    	'status', 
	    	'video', 
	    	'audio' 
	    );
	    add_theme_support( 'post-formats', $beetheme_post_formats  );
	    beetheme_default_onepgae_menu();
	}
	add_action('after_setup_theme', 'beetheme_setup');
	/**
	 * Register widget area.
	 *
	 * @since beetheme 1.0
	 *
	 * @link https://codex.wordpress.org/Function_Reference/register_sidebar
	 */
	function beetheme_widgets_init() {
		register_sidebar( array(
			'name'          => __( 'Widget Area', 'beetheme' ),
			'id'            => 'sidebar-1',
			'description'   => __( 'Add widgets here to appear in your sidebar.', 'beetheme' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}
	add_action( 'widgets_init', 'beetheme_widgets_init' );
	/**
	 * function to setup default theme menu
	 */
	function beetheme_default_onepgae_menu(){
	    $menuname 		= 'Default OnePage Menu';
	    $menulocation 	= 'default-onepage-menu';
		// Does the menu exist already?
	    $menu_exists = wp_get_nav_menu_object($menuname);
		// If it doesn't exist, let's create it.
	    if (!$menu_exists) {
	        $menu_id = wp_create_nav_menu($menuname);
			// Set up default OnePage Menu links and add them to the menu.
	        wp_update_nav_menu_item($menu_id, 0, array(
	            'menu-item-title' 	=> __('Home', 'beetheme'),
	            'menu-item-classes' => 'home',
	            'menu-item-url' 	=> '#',
	            'menu-item-status' 	=> 'publish'
	        ));
	        wp_update_nav_menu_item($menu_id, 0, array(
	            'menu-item-title' 	=> __('About', 'beetheme'),
	            'menu-item-classes' => 'About',
	            'menu-item-url' 	=> '#about',
	            'menu-item-status' 	=> 'publish'
	        ));
	        wp_update_nav_menu_item($menu_id, 0, array(
	            'menu-item-title' 	=> __('Features', 'beetheme'),
	            'menu-item-classes' => 'features',
	            'menu-item-url' 	=> '#features',
	            'menu-item-status' 	=> 'publish'
	        ));
	        wp_update_nav_menu_item($menu_id, 0, array(
	            'menu-item-title' 	=> __('Portfolio', 'beetheme'),
	            'menu-item-classes' => 'portfolio',
	            'menu-item-url' 	=> '#portfolio',
	            'menu-item-status' 	=> 'publish'
	        ));
	        wp_update_nav_menu_item($menu_id, 0, array(
	            'menu-item-title' 	=> __('Blog', 'beetheme'),
	            'menu-item-classes' => 'blog',
	            'menu-item-url' 	=> '#blog',
	            'menu-item-status' 	=> 'publish'
	        ));
	        wp_update_nav_menu_item($menu_id, 0, array(
	            'menu-item-title' 	=> __('Contact', 'beetheme'),
	            'menu-item-classes' => 'contact',
	            'menu-item-url' 	=> '#contact',
	            'menu-item-status' 	=> 'publish'
	        ));
			// Grab the theme locations and assign our newly-created menu
			// to the Beetheme Theme Default onepage menu location.
	        if (!has_nav_menu($menulocation)) {
	            $locations = get_theme_mod('nav_menu_locations');
	            $locations[$menulocation] = $menu_id;
	            echo set_theme_mod('nav_menu_locations', $locations);
	        }
	    }
	}
	function beetheme_navigation_menu() {
	    if (function_exists('wp_nav_menu')) :
		    wp_nav_menu(array(
		        'theme_location' 	=> 'fdefault-onepage-menu', 
	        	'menu_class' 		=> 'nav navbar-nav', 
	        	'menu_id' 			=> 'one', 
	        	'container' 		=> '', 
	        	'container_class' 	=> '', 
	        	'fallback_cb' 		=> 'beetheme_one_page_nav_fallback'
        	));
	    else :
	        beetheme_one_page_nav_fallback();
	    endif;
	}
	function beetheme_one_page_nav_fallback() { ?>
		<ul class="nav navbar-nav" id="one">
	        <li class="active">
	            <a href="#"><?php _e('Home', 'beetheme'); ?></a>
	        </li>
	        <li class="">
	            <a href="#about"><?php _e('About', 'beetheme'); ?></a>
	        </li>
	        <li class="">
	            <a href="#features"><?php _e('Features', 'beetheme'); ?></a>
	        </li>
	        <li class="">
	            <a href="#portfolio"><?php _e('Portfolio', 'beetheme'); ?></a>
	        </li>
	        <li class="">
	            <a href="#blog"><?php _e('Blog', 'beetheme'); ?></a>
	        </li>
	        <li class="">
	            <a href="#contact"><?php _e('Contact', 'beetheme'); ?></a>
	        </li>
	    </ul>
	    <?php
	}
	function beetheme_subnavigation_menu() {
	    if (function_exists('wp_nav_menu')) :
	        wp_nav_menu(array(
		        'theme_location' 	=> 'sub-page-menu', 
	        	'menu_class' 		=> 'nav navbar-nav', 
	        	'menu_id' 			=> 'one', 
	        	'container' 		=> '', 
	        	'container_class' 	=> '', 
	        	'fallback_cb' 		=> 'beetheme_sub_nav_menu'
	        ));
	    else :
	        beetheme_sub_nav_menu();
	    endif;
	}
	function beetheme_sub_nav_menu() {
	    ?>
	    <ul class="nav navbar-nav" id="one">
	        <?php
	        wp_list_pages('title_li=&show_home=1&sort_column=menu_order');
	        ?>
	    </ul>
	    <?php
	}
	/**
	 * Function takes thumbnail id to
	 * returns thumbnail image
	 * @param type $iw
	 * @param type $ih
	 */
	function beetheme_get_thumbnail($iw, $ih) {
	    $thumb = wp_get_attachment_url(get_post_thumbnail_id(),'full');
	    $image = aq_resize($thumb, $iw, $ih, true);
	    if ($image) {
	        print "<img src='$image' alt='image' class='img-responsive'>";
	    }
	}
	/**
	 * Function takes thumbnail id from customizers 
	 * returns thumbnail image
	 * @param type $customizer image
	 * @param type $iw
	 * @param type $ih
	 */
	function beetheme_get_customize_images($option,$default_val = '',$iw, $ih) {
		$theme_mode = get_theme_mod($option);
		if (isset($theme_mode) && $theme_mode != '') {
			$image = aq_resize($theme_mode, $iw, $ih, true);
	        print "<img src='$image' alt='image' class='img-responsive'>";
    	} elseif ($default_val) {
    		print "<img src='$default_val' alt='image' class='img-responsive'>";
    	} else {
        	return false;
    	}
	}
	function beetheme_get_theme_mod($option,$default_value = ''){
		$theme_mode = get_theme_mod($option);
		if (isset($theme_mode) && $theme_mode != '') {
        	return $theme_mode;
    	} elseif ($default_value) {
        	return $default_value;
    	} else {
        	return false;
    	}
	}
	/**
	*
	*
	*beetheme comment reply
	*/
	function beetheme_enqueue_comment_reply() {
	    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) { 
	        wp_enqueue_script( 'comment-reply' ); 
	    }
	}
	add_action( 'wp_enqueue_scripts', 'beetheme_enqueue_comment_reply' );
	/**
	*
	*
	*beetheme Breadcrumbs
	*/
	function beetheme_breadcrumbs() {
	    $delimiter = '&raquo;';
	    $home = __('Home', 'beetheme'); 
	    $before = '<span class="current">'; 
	    $after = '</span>'; 
	    echo '<div id="crumbs">';
	    global $post;
	    $homeLink = esc_url(home_url());
	    echo '<a href="' . $homeLink . '">' . $home . '</a> ' . $delimiter . ' ';
	    if (is_category()) {
	        global $wp_query;
	        $cat_obj = $wp_query->get_queried_object();
	        $thisCat = $cat_obj->term_id;
	        $thisCat = get_category($thisCat);
	        $parentCat = get_category($thisCat->parent);
	        if ($thisCat->parent != 0)
	            echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
	        echo $before . __('Archive by category', 'beetheme') . ' "' . single_cat_title('', false) . '"' . $after;
	    }
	    elseif (is_day()) {
	        echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
	        echo '<a href="' . esc_url(get_month_link(get_the_time('Y'), get_the_time('m'))) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
	        echo $before . get_the_time('d') . $after;
	    } elseif (is_month()) {
	        echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
	        echo $before . get_the_time('F') . $after;
	    } elseif (is_year()) {
	        echo $before . get_the_time('Y') . $after;
	    } elseif (is_single() && !is_attachment()) {
	        if (get_post_type() != 'post') {
	            $post_type = get_post_type_object(get_post_type());
	            $slug = $post_type->rewrite;
	            echo '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a> ' . $delimiter . ' ';
	            echo $before . get_the_title() . $after;
	        } else {
	            $cat = get_the_category();
	            $cat = $cat[0];
	            echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
	            echo $before . get_the_title() . $after;
	        }
	    } elseif (is_attachment()) {
	        $parent = get_post($post->post_parent);
	        $cat = get_the_category($parent->ID);
	        $cat = $cat[0];
	        echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
	        echo '<a href="' . esc_url(get_permalink($parent)) . '">' . $parent->post_title . '</a> ' . $delimiter . ' ';
	        echo $before . get_the_title() . $after;
	    } elseif (is_page() && !$post->post_parent) {
	        echo $before . get_the_title() . $after;
	    } elseif (is_page() && $post->post_parent) {
	        $parent_id = $post->post_parent;
	        $breadcrumbs = array();
	        while ($parent_id) {
	            $page = get_page($parent_id);
	            $breadcrumbs[] = '<a href="' . esc_url(get_permalink($page->ID)) . '">' . get_the_title($page->ID) . '</a>';
	            $parent_id = $page->post_parent;
	        }
	        $breadcrumbs = array_reverse($breadcrumbs);
	        foreach ($breadcrumbs as $crumb)
	            echo $crumb . ' ' . $delimiter . ' ';
	        echo $before . get_the_title() . $after;
	    } elseif (is_search()) {
	        echo $before . __('Search results for', 'beetheme') . ' "' . get_search_query() . '"' . $after;
	    } elseif (is_tag()) {
	        echo $before . __('Posts tagged ', 'beetheme') . '"' . single_tag_title('', false) . '"' . $after;
	    } elseif (is_author()) {
	        global $author;
	        $userdata = get_userdata($author);
	        echo $before . __('Articles posted by ', 'beetheme') . $userdata->display_name . $after;
	    } elseif (is_404()) {
	        echo $before . __('Error 404', 'beetheme') . $after;
	    }
	    if (get_query_var('paged')) {
	        if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
	            echo ' (';
	        echo __('Page', 'beetheme') . ' ' . get_query_var('paged');
	        if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
	            echo ')';
	    }
	    echo '</div>';
	}
	
	